@@ -1,38 +1,40 @@
 .listOMLRunEvaluations = function(task.id = NULL, flow.id = NULL, run.id = NULL,
-  uploader.id = NULL, tag = NULL, limit = NULL, offset = NULL, verbosity = NULL, 
-  show.array.measures = FALSE, extend.flow.name = TRUE) {
-  
+  uploader.id = NULL, tag = NULL, limit = NULL, offset = NULL, verbosity = NULL,
+  evaluation.measure = NULL, show.array.measures = FALSE, extend.flow.name = TRUE) {
+
   if (is.null(task.id) && is.null(flow.id) && is.null(run.id) && is.null(uploader.id) && is.null(tag))
     stop("Please hand over at least one of the following: task.id, flow.id, run.id, uploader.id, tag")
-  
-  api.call = generateAPICall(api.call = "json/evaluation/list", task.id = task.id, 
+  if (is.null(evaluation.measure))
+    showInfo(verbosity, "Suggestion: Use the 'evaluation.measure' argument to restrict the results to only one measure.")
+
+  api.call = generateAPICall(api.call = "json/evaluation/list", task.id = task.id,
     flow.id = flow.id, run.id = run.id, uploader.id = uploader.id,
-    tag = tag, limit = limit, offset = offset)
-  
+    tag = tag, evaluation.measure = evaluation.measure, limit = limit, offset = offset)
+
   content = doAPICall(api.call, file = NULL, method = "GET", verbosity = verbosity)
   if (is.null(content)) return(data.frame())
   evals = fromJSON(txt = content, simplifyVector = FALSE)$evaluations$evaluation
-  
+
   evals = rbindlist(lapply(evals, function(x) {
-    if(is.null(x$value)) x$value = NA
-    if(is.null(x$array_data)) x$array_data = NA else x$array_data = collapse(x$array_data)
-    cols = c("run_id", "task_id", "setup_id", "flow_id", "flow_name", "data_name", 
+    if (is.null(x$value)) x$value = NA
+    if (is.null(x$array_data)) x$array_data = NA else x$array_data = collapse(x$array_data)
+    cols = c("run_id", "task_id", "setup_id", "flow_id", "flow_name", "data_name",
       "upload_time", "function", "value", "array_data")
     x[cols]
   }))
-  
+
   # convert long format to wide format
   setnames(evals, "function", "fun")
   form = run_id + task_id + setup_id + flow_id + flow_name + data_name + upload_time ~ fun
   evals = dcast(data = evals, formula = form, value.var = c("value", "array_data"))
-  
+
   # drop "all NA" columns
   evals = as.data.frame(evals)[, vlapply(evals, function(x) !all(is.na(x)))]
   # drop all array columns that are NULL
   #drop.array = vlapply(evals[,grepl("array_data[_]", colnames(evals))], function(x) all(vlapply(x, is.null)))
   #drop.array = names(drop.array)[drop.array]
   #evals = evals[, colnames(evals)%nin%drop.array]
-  
+
   # unfortunately column names are f***ed up now. Some tedious work is neccessary
   # to achive our naming conventions
   colnames(evals) = stri_replace_all_fixed(colnames(evals), "value_", "")
@@ -41,19 +43,19 @@
   if (!show.array.measures) {
     evals = evals[,!arr.ind]
   }
-  
+
   # convert types (by default all is character)
   #evals = as.data.frame(lapply(evals, type.convert, numerals = "no.loss", as.is = TRUE))
-  
+
   # finally convert _ to . in col names
   names(evals) = convertNamesOMLToR(names(evals))
-  
+
   # split flow.name into learner.name, version and flow.source
   if (extend.flow.name) {
     # extract flow.version
-    flow.version = stri_match_last(evals$flow.name, 
+    flow.version = stri_match_last(evals$flow.name,
       regex = "[[:digit:]]+\\.*[[:digit:]]*")
-    
+
     # extract flow.source
     src = c("weka", "mlr", "moa", "sklearn", "rm", "HubMiner", "classif", "regr", "surv", "openml")
     src = stri_paste("^", src)
@@ -73,7 +75,7 @@
       values = list(flow.version = flow.version, flow.source = flow.source, learner.name = learner.name)),
       stringsAsFactors = FALSE)
   }
-  
+
   return(evals)
 }
 
@@ -89,12 +91,17 @@
 #' @template note_memoise
 #'
 #' @inheritParams listOMLRuns
-#' @param show.array.measures
-#'  Should measures that return an array (i.e. confusion matrix, predictive accuracy per cv-fold) instead of a single skalar value be shown?
+#' @param evaluation.measure [\code{character(1)}]\cr
+#'  Use this to speedup your request.
+#'  It restricts the results to only one evaluation measure (see \code{\link{listOMLEvaluationMeasures}} for possible values).
+#'  Default is \code{NULL}, which means that no restriction is going to happen and all possible evaluation measures will be returned.
+#' @param show.array.measures [\code{logical(1)}]\cr
+#'  Should measures that return an array instead of a single skalar value be shown (e.g. confusion matrix, predictive accuracy within each class)?
 #'  Default is \code{FALSE}.
-#' @param extend.flow.name
-#'  Adds a column \code{flow.version} that refers to the version number of the flow and a column \code{flow.source} containing the prefix of the flow that specifies the source of the flow (i.e. weka, R) and a column \code{learner.name} that refers to the learner. Default is \code{TRUE}.
-#'   
+#' @param extend.flow.name [\code{logical(1)}]\cr
+#'  Adds a column \code{flow.version} that refers to the version number of the flow and a column \code{flow.source} containing the prefix of the flow that specifies the source of the flow (i.e. weka, R) and a column \code{learner.name} that refers to the learner.
+#'  Default is \code{TRUE}.
+#'
 #' @return [\code{data.frame}].
 #' @family list
 #' @export
